parallelism_choicesList the types of supported parallel computing.
parallelism_choices()Character vector listing the types of parallel computing supported.
Run make(..., parallelism = x, jobs = n) for any of
the following values of x to distribute targets over parallel
units of execution.
launches multiple processes in a single R session
using parallel::parLapply().
This is single-node, (potentially) multicore computing.
It requires more overhead than the "mclapply" option,
but it works on Windows. If jobs is 1 in
make(), then no "cluster" is created and
no parallelism is used.
uses multiple processes in a single R session.
This is single-node, (potentially) multicore computing.
Does not work on Windows for jobs > 1
because mclapply() is based on forking.
uses multiple R sessions
by creating and running a Makefile.
The Makefile is NOT standalone.
DO NOT run outside of make() or make().
Windows users will need to download and intall Rtools.
As explained in the vignettes, you can use the prepend
to make() or make() to distribute
targets over multiple nodes of a supercomputer. Use this
approach for true distributed computing.